admin Package
=============

:mod:`admin` Package
--------------------

.. automodule:: CMFDefault.browser.admin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`config` Module
--------------------

.. automodule:: CMFDefault.browser.admin.config
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`interfaces` Module
------------------------

.. automodule:: CMFDefault.browser.admin.interfaces
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`syndication` Module
-------------------------

.. automodule:: CMFDefault.browser.admin.syndication
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    CMFDefault.browser.admin.tests

